# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKOptimizersv4Python



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkAmoebaOptimizerv4Python
else:
    import _itkAmoebaOptimizerv4Python

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkOptimizerParametersPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.itkArrayPython
import itk.itkSingleValuedNonLinearVnlOptimizerv4Python
import itk.itkObjectToObjectOptimizerBasePython
import itk.itkOptimizerParameterScalesEstimatorPython
import itk.itkObjectToObjectMetricBasePython
import itk.itkSingleValuedCostFunctionv4Python
import itk.itkCostFunctionPython

def itkAmoebaOptimizerv4_New():
    return itkAmoebaOptimizerv4.New()

class itkAmoebaOptimizerv4(itk.itkSingleValuedNonLinearVnlOptimizerv4Python.itkSingleValuedNonLinearVnlOptimizerv4):
    r"""Proxy of C++ itkAmoebaOptimizerv4 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkAmoebaOptimizerv4_Pointer"""
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkAmoebaOptimizerv4_Pointer"""
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_Clone(self)

    def StartOptimization(self, doOnlyInitialization=False):
        r"""
        StartOptimization(self, doOnlyInitialization=False)

        Parameters
        ----------
        doOnlyInitialization: bool

        """
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_StartOptimization(self, doOnlyInitialization)

    def SetAutomaticInitialSimplex(self, _arg):
        r"""
        SetAutomaticInitialSimplex(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_SetAutomaticInitialSimplex(self, _arg)

    def AutomaticInitialSimplexOn(self):
        r"""AutomaticInitialSimplexOn(self)"""
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_AutomaticInitialSimplexOn(self)

    def AutomaticInitialSimplexOff(self):
        r"""AutomaticInitialSimplexOff(self)"""
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_AutomaticInitialSimplexOff(self)

    def GetAutomaticInitialSimplex(self):
        r"""GetAutomaticInitialSimplex(self) -> bool"""
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_GetAutomaticInitialSimplex(self)

    def SetOptimizeWithRestarts(self, _arg):
        r"""
        SetOptimizeWithRestarts(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_SetOptimizeWithRestarts(self, _arg)

    def OptimizeWithRestartsOn(self):
        r"""OptimizeWithRestartsOn(self)"""
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_OptimizeWithRestartsOn(self)

    def OptimizeWithRestartsOff(self):
        r"""OptimizeWithRestartsOff(self)"""
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_OptimizeWithRestartsOff(self)

    def GetOptimizeWithRestarts(self):
        r"""GetOptimizeWithRestarts(self) -> bool"""
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_GetOptimizeWithRestarts(self)

    def SetInitialSimplexDelta(self, initialSimplexDelta, automaticInitialSimplex=False):
        r"""
        SetInitialSimplexDelta(self, initialSimplexDelta, automaticInitialSimplex=False)

        Parameters
        ----------
        initialSimplexDelta: itkOptimizerParametersD
        automaticInitialSimplex: bool

        """
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_SetInitialSimplexDelta(self, initialSimplexDelta, automaticInitialSimplex)

    def GetInitialSimplexDelta(self):
        r"""GetInitialSimplexDelta(self) -> itkOptimizerParametersD"""
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_GetInitialSimplexDelta(self)

    def SetParametersConvergenceTolerance(self, _arg):
        r"""
        SetParametersConvergenceTolerance(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_SetParametersConvergenceTolerance(self, _arg)

    def GetParametersConvergenceTolerance(self):
        r"""GetParametersConvergenceTolerance(self) -> double"""
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_GetParametersConvergenceTolerance(self)

    def SetFunctionConvergenceTolerance(self, _arg):
        r"""
        SetFunctionConvergenceTolerance(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_SetFunctionConvergenceTolerance(self, _arg)

    def GetFunctionConvergenceTolerance(self):
        r"""GetFunctionConvergenceTolerance(self) -> double"""
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_GetFunctionConvergenceTolerance(self)

    def GetOptimizer(self):
        r"""GetOptimizer(self) -> vnl_amoeba *"""
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_GetOptimizer(self)
    __swig_destroy__ = _itkAmoebaOptimizerv4Python.delete_itkAmoebaOptimizerv4

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkAmoebaOptimizerv4

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_cast(obj)

    def New(*args, **kargs):
        """New() -> itkAmoebaOptimizerv4

        Create a new object of the class itkAmoebaOptimizerv4 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkAmoebaOptimizerv4.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkAmoebaOptimizerv4.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkAmoebaOptimizerv4.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkAmoebaOptimizerv4 in _itkAmoebaOptimizerv4Python:
_itkAmoebaOptimizerv4Python.itkAmoebaOptimizerv4_swigregister(itkAmoebaOptimizerv4)

